C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
       subroutine db_get_irphase(npts,indat_bt,icode)
C!F77-------------------------------------------------------------------
c!Description: This technique identifies single pixel phase strictly
c              by the value of the 8-11 micron BTDIF.  This was
c              originally designed by Bryan Baum.  Eventually, this
c              will be modified to use the third channel in the 
c              tri-spectral technique (12 micron) so that more 
c              accurate results can be obtained.  This is the version
c              used to process Direct Broadcast data (MODIS product
c              MOD06).
c 
c!Input Parameters:
c npts     Number of points in this particular set
c indat_bt Array which holds the brightness temperature information
c          and the spatial variance info. for the current scan
c 
c!Output Parameters: 
c icode    Output cloud phase identifier
c
c!Revision History:
c
c!Team-unique Header:
c
c!References and Credits:
c
c!Design Notes:
c!End------------------------------------------------------------------ 
      implicit none
      save
 
      include 'db_mod06uw_data.inc'
      include 'db_mod06uw_debug.inc'

c ... scalar arguments
      integer npts

c ... array arguments
      integer icode( max_samp_line*max_samp_pixel ),
     +        indat_bt( max_samp_line*max_samp_pixel , irphase_band+5 )

c ... local scalars
      integer maxc,loop,knt
      real bt8,bt11

c ... local arrays ..
      real btd8m11
 

c ...  debug statement ............................................
       if (debug .gt. 0) then
         write( h_output, '(72(''-''))' )
         write(h_output,'(2x/,''Subroutine get_irphase  '',/)')
       endif
c .................................................................

c ...   Initialize output

        maxc = npts

c ...   initialize the icode vector 
        do knt=1,maxc
                icode(knt) = -1

c ...           flag boxes as being clear sky - value of clr_data
c ...             is -999
                if (indat_bt(knt,1) .eq. clr_data) then
                  icode(knt) = 0  
                endif

c ...           flag scenes where the input data were bad
c ...             value of clr_misg is 100
                if (indat_bt(knt,1) .eq. out_misg) then
                        icode(knt) =  clr_misg     
                endif
        enddo

c ...
c ...   Point by point identification 

        do loop = 1,maxc

c ...     Set up brightness temperatures and brightness temperature 
c ...       differences
          bt8  = indat_bt(loop,1)/100.
          bt11 = indat_bt(loop,2)/100.
  
          btd8m11 = bt8 - bt11
  
c         ************************************
c          Output phase identification codes
c         ************************************
c         Value  Meaning
c         -----  ------- 
c           0    cloud free 
c           1    water cloud 
c           2    ice cloud
c           3    mixed phase cloud
c           4    also ice cloud (redundant)
c           5    also water cloud (redundant)
c           6    undecided
c           100  means missing data (called clr_misg)

c         23 February 2001 - Bryan Baum
c         attempting to code the FORTRAN equivalent of SN's matlab
c         simphase.m code

          if (icode(loop).eq.-1) then
 
c ...         Flag as ice cloud
              if (bt11 .le. 238.0 .or. btd8m11 .ge. 0.5) then
                  icode(loop) = 2  

c ...         Flag as mixed-phase cloud
              else if (bt11 .gt. 238.0  .and.
     +                 bt11 .lt. 268.0  .and.
     +                 btd8m11 .ge. -0.25 .and.
     +                 btd8m11 .lt. 0.5) then
                   icode(loop) = 3  

c ...         Flag as uncertain phase cloud
              else if (bt11 .gt. 238.0  .and.
     +                 bt11 .lt. 268.0  .and.
     +                 btd8m11 .lt. -0.25  .and. 
     +                 btd8m11 .ge. -1.0) then
                  icode(loop) = 6  

c ...         Flag as water cloud
              else if (bt11 .gt. 238.0  .and.
     +            btd8m11 .le. -1.0 ) then                  
                  icode(loop) = 1  

c ...         Flag as water cloud
              else if (bt11 .ge. 285.0   .and.
     +            btd8m11 .le. -0.5 ) then                  
                  icode(loop) = 1  

c ...         Flag what's left as uncertain
              else 
                  icode(loop) = 6

              endif
     
          endif
  
c ....... debug statement ..........................................
          if (debug .gt. 2) then
            write( h_output, '(72(''-''))' )
            write(h_output,'(2x/,''IR phase output '',/)')
            write(h_output,'(''bt11,bt8,bt8m11,icode: '')')
            write(h_output,'(3f10.3,i10)') bt11,bt8,btd8m11,
     *        icode(loop)
          endif
c .................................................................

      enddo
     
      return
      end
