C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
       subroutine db_put_irphase_out_arrays(npixels,icode,indat_bt,var)

C!F77------------------------------------------------------------------
c!Description: Place the processing variables into the
c    output variables.  This requires going from one and two
c    dimension processing arrays into a two or 3 dimensioned
c    output arrays.
c
c!Input Parameters:
c     npixels                    Number of pixels in scan
c
c           Processing arrays:
c    icode                       holds 1D array of phase product
c    indat_bt                    holds bt values for processing
c    var                         holds variance values for processing
c
c!Output Parameters:   None
c
c!Revision History:
c
c!Team-unique Header:
c
c!References and Credits:
c   K. Strabala (kathys@ssec.wisc.edu)
c   See Cloud Mask ATBD-MOD-04 and HDF specs.
c
c!DESIGN NOTES:
c
c    The following arrays in COMMON /MOD06_DATA/ are filled:
c    brightess_diff              Brightness temperature difference
c                                 between 8-11 and 11-12
c    radiance_variance           Variance of radiances over box
c                                 for all three ir phase bands
c    cloud_phase                 Tri-spectral irphase result

c!END-------------------------------------------------------------------
      implicit none
      save

      include 'db_mod06uw_data.inc'
 
c ... scalar arguments
      integer npixels
c     array arguments
      integer indat_bt( max_samp_line*max_samp_pixel , irphase_band+5 ),
     +        icode( max_samp_line*max_samp_pixel )
      real var ( max_samp_line*max_samp_pixel , irphase_band )


c ... local variables
      integer line, pixel, kount, kount1, kount2, bnd

c ... initalize
      kount = 0
      kount1 = 0
      kount2 = 0

c ... first place actual phase code result and ecosystme into the 
c ...  output product array
c ...
      do line = 1, ( max_line / isamp ) 
         do pixel = 1, ( npixels / isamp ) 
            kount = kount + 1
            if (icode(kount) .ne. 100) 
     +      cloud_phase( pixel, line ) = real(icode(kount))
         end do 
       end do

c ... Next the brightness temperature differences
      do line = 1, ( max_line / isamp ) 
         do pixel = 1, ( npixels / isamp ) 
            kount2 = kount2 + 1 
            do bnd = 1 , phase_pairs
               if (indat_bt(kount2,bnd+3) .gt. -998) then
                 brightness_diff(pixel,line,bnd) =
     +              real(indat_bt(kount2,bnd+3)/100.0)
               endif
            end do
         end do
      end do

c ... Next the radiance variance 
      do line = 1, ( max_line / isamp ) 
         do pixel = 1, ( npixels / isamp ) 
            kount1 = kount1 + 1 
            do bnd = 1 , irphase_band
               radiance_variance(pixel,line,bnd) =  var(kount1,bnd)
            end do
         end do
      end do

      return
      end
