C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine extemp( tt, slat )

c-----------------------------------------------------------------------
c
c!F77
c
c!Description:
c    Extrapolate a temperature profile defined at the 40 standard
c    pressure levels up to 0.1 hPa.
c
c    The 40 standard pressure levels are as follows (hPa):
c      .1,.2,.5,1.,1.5,2.,3.,4.,5.,7.,10.,15.,20.,25.,30.,
c      50.,60.,70.,85.,100.,115.,135.,150.,200.,250.,300.,350.,400.,
c      430.,475.,500.,570.,620.,670.,700.,780.,850.,920.,950.,1000.
c
c!Input Parameters:
c    TT      Temperature profile (K) with -1.0 at missing levels
c    SLAT    Latitude (deg)
c
c!Output Parameters:
c    EXTEMP  Temperature profile with missing values filled
c
c!Revision History:
c
c!Team-unique Header:
c
c!End
c
c-----------------------------------------------------------------------

      implicit none
      
c ... arguments

      real tt( 40 ), slat

c ... local variables
      
      integer nl, nx, nc, ny
      parameter ( nl = 3, nx = 6, nc = nx+1, ny = 15 )

      integer i, init, j, k, lx(nx)
      real alat, c1, c2, c3, cc(nl,nc,ny), cfl(nc), cy, plat(nl), sum,
     &  tx(nx), x1, x2, x3, xx, y1, y2, y3, coef(nc,ny,nl)

c ... save statement

      save
      
c ... common block

      common /extcof/ coef

c ... data statements

      data init/1/, lx/35,31,26,24,20,16/, x1/75./, x2/45./, x3/15./

      if(init.ne.0) then
         do j=1,ny
            do i=1,nc
               y1=coef(i,j,1)
               y2=coef(i,j,2)
               y3=coef(i,j,3)
               call cofit3(x1,x2,x3,y1,y2,y3,c1,c2,c3)
               cc(1,i,j)=c1
               cc(2,i,j)=c2
               cc(3,i,j)=c3
            enddo
         enddo
         init=0
      endif

      alat=abs(slat)
      xx=1.

      do k=1,nl
         plat(k)=xx
         xx=xx*alat
      enddo

      do i=1,nx
         j=lx(i)
         tx(i)=tt(j)
      enddo

      do j=1,ny
         if(tt(j).gt.0.0) return
         do i=1,nc
            cy=0.
            do k=1,nl
               cy=cy+cc(k,i,j)*plat(k)
            enddo
            cfl(i)=cy
         enddo
         sum=cfl(nc)
         do i=1,nx
            sum=sum+cfl(i)*tx(i)
         enddo
         tt(j)=sum
      enddo

      end

c-----------------------------------------------------------------------

      block data xtcoef

      integer nl, nx, nc, ny
      parameter ( nl = 3, nx = 6, nc = nx+1, ny = 15 )

      integer i, j
      real coef( nc, ny, nl )

      save
      
      common /extcof/ coef

      data ((coef(i,j,1),i=1,nc),j=1,ny)/
     *   0.0030, -0.4122,  0.2104, -0.2353,  0.0945,  0.1706, 293.0100,
     *   0.1869, -0.2832,  0.2494,  0.1544, -0.1125,  0.2569, 154.0889,
     *   0.4267,  0.0462,  0.2420,  0.7426, -0.2284,  0.1978, -69.3933,
     *   0.6674,  0.0833,  0.3362,  0.6991, -0.2295,  0.4542,-209.0515,
     *   0.5543,  0.2496,  0.3585,  0.8005, -0.4661,  0.6072,-234.0684,
     *   0.4743,  0.3667,  0.3746,  0.8772, -0.6403,  0.7184,-251.9551,
     *   0.4032,  0.3471,  0.2671,  0.6737, -0.6346,  0.8598,-199.2074,
     *   0.1574,  0.4218,  0.2896,  0.4731, -0.5589,  0.9468,-155.3909,
     *  -0.0298,  0.4794,  0.3045,  0.3378, -0.5133,  1.0161,-123.7185,
     *  -0.2250,  0.5391,  0.2414,  0.1667, -0.5031,  1.2056, -85.1810,
     *  -0.1802,  0.3379,  0.2342,  0.0368, -0.4720,  1.3296, -56.3577,
     *  -0.1403,  0.2063,  0.1671,  0.0144, -0.3724,  1.2859, -30.4098,
     *  -0.1142,  0.1149,  0.1227, -0.0150, -0.2910,  1.2531, -11.6513,
     *  -0.0943,  0.0792,  0.0985, -0.0047, -0.2119,  1.2039, -12.3730,
     *  -0.0746,  0.0492,  0.0765,  0.0059, -0.1443,  1.1621, -14.0130/
      data ((coef(i,j,2),i=1,nc),j=1,ny)/
     *   0.6055, -0.5999,  0.1783,  0.4776,  0.2891, -0.2045,  66.9102,
     *   0.5322, -0.3325,  0.2039,  0.4003,  0.4351, -0.1836,   4.4326,
     *   0.6016, -0.1784,  0.3375,  0.2921,  0.7642, -0.3375, -85.7488,
     *   0.5830, -0.0216,  0.4294,  0.3836,  0.7595, -0.3886,-146.2202,
     *   0.5871,  0.0479,  0.3625,  0.3444,  0.7743, -0.3687,-152.6067,
     *   0.5923,  0.0970,  0.3136,  0.3181,  0.7845, -0.3557,-157.4324,
     *   0.5949, -0.0149,  0.2512,  0.1354,  0.5849, -0.0015,-116.9559,
     *   0.5196, -0.0341,  0.2578,  0.0360,  0.4254,  0.1976, -86.1359,
     *   0.4595, -0.0480,  0.2654, -0.0344,  0.3000,  0.3509, -63.4169,
     *   0.3372,  0.0916,  0.3325,  0.0032,  0.2223,  0.6264,-138.4715,
     *   0.2951,  0.1129,  0.2677, -0.0033,  0.1056,  0.7890,-131.8596,
     *   0.1905,  0.1257,  0.2275,  0.0112,  0.0755,  0.7943, -99.9765,
     *   0.1085,  0.1354,  0.2097,  0.0135,  0.0520,  0.8018, -76.5450,
     *   0.0788,  0.0770,  0.2066, -0.0032,  0.0280,  0.8658, -59.6573,
     *   0.0538,  0.0296,  0.2050, -0.0147,  0.0077,  0.9177, -46.2681/
      data ((coef(i,j,3),i=1,nc),j=1,ny)/
     *   0.0557,  0.0549, -0.9796,  0.8427, -0.5035, -0.6448, 498.3794,
     *   0.0755, -0.0686, -0.5784,  0.4568, -0.3291, -0.4956, 458.0688,
     *  -0.0236, -0.0562, -0.1700,  0.0409, -0.1599, -0.2423, 400.6909,
     *  -0.0858,  0.0407,  0.1097, -0.2153, -0.0946, -0.0222, 325.7112,
     *  -0.1664,  0.2078,  0.0294, -0.1698, -0.2470,  0.0091, 334.6926,
     *  -0.2107,  0.2985,  0.0081, -0.1244, -0.3584,  0.0673, 326.3660,
     *  -0.1126,  0.3427, -0.0445, -0.0125, -0.3688,  0.3074, 218.6801,
     *  -0.0370,  0.2349,  0.0761, -0.0088, -0.3091,  0.3636, 167.3085,
     *   0.0236,  0.1786,  0.0982,  0.0235, -0.2538,  0.3837, 133.5242,
     *  -0.0025,  0.1083,  0.1871, -0.1371, -0.2147,  0.3658, 163.7505,
     *   0.0867, -0.0702,  0.2592, -0.1866, -0.1037,  0.3047, 165.0714,
     *   0.1339, -0.0777,  0.2304, -0.1618, -0.0664,  0.3609, 129.7949,
     *   0.1633, -0.0750,  0.2239, -0.1572, -0.0328,  0.3936, 103.3754,
     *   0.0728, -0.0599,  0.2212, -0.1488, -0.0047,  0.4815,  96.1188,
     *  -0.0126, -0.0420,  0.2265, -0.1487,  0.0275,  0.5451,  91.4538/
      end

c-----------------------------------------------------------------------

      subroutine cofit3( xx1, xx2, xx3, yy1, yy2, yy3, c0, c1, c2 )
c-----------------------------------------------------------------------
c
c!F77
c
c!Description:
c  Routine to obtain coefficients of 3-point parabolic fit.
c
c!Input Parameters:
c    xx1     Real x value of Point 1
c    xx2     Real x value of Point 2
c    xx3     Real x value of Point 3
c    yy1     Real y value of point 1
c    yy2     Real y value of point 2
c    yy3     Real y value of point 3
c
c!Output Parameters:
c    c0      Real coefficient 1 
c    c1      Real coefficient 2 
c    c2      Real coefficient 3 
c
c!Revision History:
c    04-DEC-1997 Liam Gumley, CIMSS/SSEC
c                Modified Hal Woolf's version to meet ECS standards
c    15-DEC-1997 Liam Gumley, CIMSS/SSEC
c                Added SAVE statement to BLOCK DATA code
c
c!Team-unique Header:
c
c!End
c
c-----------------------------------------------------------------------

      implicit none

c ... arguments

      real xx1, xx2, xx3, yy1, yy2, yy3, c0, c1, c2

c ... local variables

      real det, t1, t2, t3, x1, x12, x2, x22, x3, x32, y1, y2, y3

      x1 = xx1
      x2 = xx2
      x3 = xx3
      y1 = yy1
      y2 = yy2
      y3 = yy3
      x12 = x1*x1
      x22 = x2*x2
      x32 = x3*x3
      t1 = x2*x32 - x3*x22
      t2 = -(x1*x32 - x3*x12)
      t3 = x1*x22 - x2*x12
      det = t1 + t2 + t3
      c0 = (y1*t1 + y2*t2 + y3*t3)/det
      c1 =((y2*x32 - y3*x22) - (y1*x32 - y3*x12) + (y1*x22 - y2*x12))/
     1  det
      c2 =((x2*y3 - x3*y2) - (x1*y3 - x3*y1) + (x1*y2 - x2*y1))/det

      end

c-----------------------------------------------------------------------
