C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      real function modrad( tskn, temp, tau, band, nl )

c-----------------------------------------------------------------------
c
c!F77
c
c!Description:
c    Compute MODIS IR band radiance at top of atmosphere.
c
c!Input Parameters:
c    TSKN      Surface skin temperature (K)
c    TEMP      Temperature profile (K) at NL levels
c    TAU       Transmittance profile (no units) at NL levels
c    BAND      MODIS IR band number (20-25,27-36)
c    NL        Number of levels in TEMP and TAU profiles
c
c!Output Parameters:
c    MODRAD    Radiance at top of atmosphere
c              (milliWatts per square meter per steradian per
c              inverse centimeter)
c
c!Revision History:
c
c!Team-unique Header:
c
c!End
c
c-----------------------------------------------------------------------

      implicit none

c ... Arguments

      real tskn, temp(*), tau(*)
      integer band, nl

c ... Local variables

      real b1, b2, bsts, rad, t1, t2, tau1, tau2
      integer i

c ... Parameters
      
      integer units
      parameter ( units = 0 )
      
c ... External function

      real modis_planck
      external modis_planck

c ... Initialize

      tau1 = tau( 1 )
      t1 = temp(  1)
      b1 = modis_planck( t1, band, units )
      rad = 0.0

c ... Compute RTE
      
      do i = 2, nl
        tau2 = tau( i )
        t2 = temp( i )
        b2 = modis_planck( t2, band, units )
        rad = rad + 0.5 * ( b1 + b2 ) * ( tau1 - tau2 )
        tau1 = tau2
        b1 = b2
      end do

c ... Add surface contribution
  
      if ( tskn .gt. 0.0 ) then
        bsts = modis_planck( tskn, band, units ) * tau1
        rad = rad + bsts
      endif

c ... Set return value
      
      modrad = rad

      end
