C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      REAL FUNCTION SVPWAT( TEMP )

C-----------------------------------------------------------------------
C !F77
C
C !DESCRIPTION:
C Compute saturation vapor pressure over water for a given temperature.
C
C !INPUT PARAMETERS:
C REAL            TEMP        Temperature (K)
C
C !OUTPUT PARAMETERS:
C REAL            SVPWAT      Saturation vapor pressure over water (mb)
C
C !REVISION HISTORY:
C
c!Team-Unique Header:
c    Developed by the MODIS Group, CIMSS/SSEC, UW-Madison.
C
C !END
C-----------------------------------------------------------------------

      implicit none

c ... arguments

      real temp
      
c ... local variables

      double precision b,s,t,a0,a1,a2,a3,a4,a5,a6,a7,a8,a9

c ... data statements

      data a0/.999996876d0/,a1/-.9082695004d-2/,a2/.7873616869d-4/,
     *  a3/-.6111795727d-6/,a4/.4388418740d-8/,a5/-.2988388486d-10/,
     *  a6/.2187442495d-12/,a7/-.1789232111d-14/,a8/.1111201803d-16/,
     *  a9/-.3099457145d-19/,b/.61078d+1/
     
      t = dble( temp - 273.16 )
      s = a0 + 
     &  t*(a1+t*(a2+t*(a3+t*(a4+t*(a5+t*(a6+t*(a7+t*(a8+t*a9))))))))
      s = b / s**8
      svpwat = real( s )

      END
